==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/de.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-Mail",
    "Loading accounts" : "Lade Konten",
    "Error while loading the accounts." : "Fehler beim Laden der Konten.",
    "Error while loading the selected account." : "Fehler beim Laden des ausgewählten Kontos.",
    "Can not load this folder." : "Dieser Ordner kann nicht geladen werden.",
    "Searching for {query}" : "Suche nach {query}",
    "Error while deleting message." : "Fehler beim Löschen der Nachricht.",
    "Forwarded message" : "Weitergeleitete Nachricht",
    "Choose a folder to store the attachment in" : "Ordner zum Speichern des Anhangs auswählen",
    "Attachments saved to Files." : "Anhänge wurde in Dateien gespeichert.",
    "Attachment saved to Files." : "Anhang wurde in Dateien gespeichert.",
    "Error while saving attachments to Files." : "Fehler beim Speichern der Anhänge unter Dateien.",
    "Error while saving attachment to Files." : "Fehler beim Speichern des Anhangs unter Dateien.",
    "Message flag could not be set." : "Nachrichten-Kennzeichnung konnte nicht gesetzt werden.",
    "Could not move message." : "Nachricht konnte nicht verschoben werden.",
    "Invalid account" : "Ungültiges Benutzerkonto",
    "Invalid folder" : "Ungültiger Ordner",
    "Error while creating the account: " : "Fehler beim Erstellen eines Kontos:",
    "Unknown error" : "Unbekannter Fehler",
    "Error while updating the account: " : "Fehler beim Aktualisieren des Kontos:",
    "All inboxes" : "Alle Posteingänge",
    "you" : "Du",
    "Send message to {email}" : "Nachricht an {email} senden",
    "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
    "There was a problem loading {tag}{name}{endtag}" : "Beim Laden von {tag}{name}{endtag} ist ein Problem aufgetreten",
    "Could not load your message" : "Deine Nachricht konnte nicht geladen werden",
    "Could not load the desired message" : "Gewünschte Nachricht konnte nicht geladen werden",
    "Could not load the message" : "Nachricht konnte nicht geladen werden",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n neue Nachricht\nvon {from}","%n neue Nachrichten\nvon {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Speichern",
    "Saved" : "Gespeichert",
    "Show all folders" : "Alle Ordner anzeigen",
    "Collapse folders" : "Ordner einklappen",
    "Error while deleting account." : "Fehler beim Löschen des Kontos.",
    "Choose a file to add as attachment" : "Wähle eine Datei, die als Anhang angefügt werden soll",
    "An error occurred while uploading {fname}" : "Fehler aufgetreten beim Hochladen von  {fname}",
    "Reply" : "Antworten",
    "Send" : "Senden",
    "Sending …" : "Sende…",
    "Message sent!" : "Nachricht versandt!",
    "Server error" : "Serverfehler",
    "An unknown error occurred" : "Unbekannter Fehler aufgetreten",
    "Opening HTML drafts is not supported yet." : "Das Öffnen von HTML-Entwürfen wird noch nicht unterstützt.",
    "No writable calendars found" : "Keine beschreibbaren Kalender gefunden",
    "Error while importing the calendar event" : "Fehler beim Importieren des Kalenderereignis",
    "Error while downloading calendar event" : "Fehler beim Herunterladen des Kalenderereignis",
    "& others" : "& weitere",
    "Error while loading messages." : "Fehler beim Laden der Nachrichten.",
    "Error while refreshing messages." : "Fehler beim Aktualisieren der Nachrichten.",
    "Setting up your account" : "Dein Konto wird eingerichtet",
    "Inbox" : "Posteingang",
    "Sent" : "Gesendet",
    "Drafts" : "Entwürfe",
    "Archive" : "Archiv",
    "Trash" : "Papierkorb",
    "Junk" : "Spam",
    "All" : "Alle",
    "Favorites" : "Favoriten",
    "Auto detect failed. Please use manual mode." : "Automatische Erkennung fehlgeschlagen. Bitte nutze den manuellen Modus.",
    "Updating account failed: " : "Kontoaktualisierung fehlgeschlagen:",
    "Creating account failed: " : "Kontoerstellung fehlgeschlagen:",
    "Delete permanently" : "Endgültig löschen",
    "Error loading message" : "Fehler beim Laden der Nachricht",
    "Settings" : "Einstellungen",
    "Forwarding to %s" : "Weiterleiten an %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klicke hier, wenn Du nicht automatisch innerhalb der nächsten Sekunden weitergeleitet wirst.",
    "Redirect" : "Weiterleiten",
    "The link leads to %s" : "Der Link führt nach %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Wenn Du diese Seite nicht besuchen möchtest, kannst Du zu <a href=\"%s\">Mail</a> zurückkehren.",
    "Continue to %s" : "Weiter nach %s",
    "Delete account" : "Konto löschen",
    "Try again" : "Nochmals versuchen",
    "New message" : "Neue Nachricht",
    "Account Settings" : "Konto-Einstellungen",
    "Aliases" : "Aliasse",
    "Mail address" : "E-Mail-Adresse",
    "Display Name" : "Anzeigename",
    "Account" : "Konto",
    "Keyboard shortcuts" : "Tastenkürzel",
    "Speed up your Mail experience with these quick shortcuts." : "Verbessere Deine Arbeit mit Mail durch diese Schnellbefehle.",
    "Compose new message" : "Neue Nachricht erstellen",
    "Newer message" : "Neuere Nachricht",
    "Older message" : "Ältere Nachricht",
    "Toggle star" : "Stern umschalten",
    "Toggle unread" : "Ungelesen umschalten",
    "Delete" : "Löschen",
    "Search" : "Suchen",
    "Refresh" : "Aktualisieren",
    "Connect your mail account" : "Verbinde Deine E-Mail-Konto",
    "Name" : "Name",
    "Mail Address" : "E-Mail-Adresse",
    "Password" : "Passwort",
    "Manual configuration" : "Manuelle Einrichtung",
    "IMAP Host" : "IMAP-Host",
    "IMAP security" : "IMAP-Sicherheit",
    "None" : "Keine",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-Port",
    "IMAP User" : "IMAP-Benutzer",
    "IMAP Password" : "IMAP-Passwort",
    "SMTP Host" : "SMTP-Host",
    "SMTP security" : "SMTP-Sicherheit",
    "SMTP Port" : "SMTP-Port",
    "SMTP User" : "SMTP-Benutzer",
    "SMTP Password" : "SMTP-Passwort",
    "Connect" : "Verbinden",
    "from" : "von",
    "to" : "an",
    "cc" : "cc",
    "bcc" : "bcc",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Diese E-Mail wurde von einer No-Reply-Adresse gesendet und Deine Antwort wird wahrscheinlich nicht gelesen",
    "Subject" : "Betreff",
    "Save all to Files" : "Alles unter Dateien sichern",
    "Add mail account" : "E-Mail-Konto hinzufügen",
    "Use Gravatar and favicon avatars" : "Gravatar- und Favicon-Avatare verwenden",
    "No search results for" : "Keine Suchergebnisse für",
    "The images have been blocked to protect your privacy." : "Die Bilder wurden blockiert um Deine Privatsphäre zu schützen.",
    "Show images from this sender" : "Bilder dieses Absenders anzeigen",
    "Forward" : "Weiterleiten",
    "No messages in this folder!" : "Keine Nachrichten in diesem Ordner",
    "Upload attachment" : "Anhang hochladen",
    "Add attachment from Files" : "Anhang von \"Dateien\" hinzufügen",
    "Import into calendar" : "In Kalender importieren",
    "Download attachment" : "Anhang herunterladen",
    "Save to Files" : "Unter Dateien speichern"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/de.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-Mail",
    "Loading accounts" : "Lade Konten",
    "Error while loading the accounts." : "Fehler beim Laden der Konten.",
    "Can not load this folder." : "Dieser Ordner kann nicht geladen werden.",
    "Searching for {query}" : "Suche nach {query}",
    "Error while deleting message." : "Fehler beim Löschen der Nachricht.",
    "Forwarded message" : "Weitergeleitete Nachricht",
    "Choose a folder to store the attachment in" : "Ordner zum Speichern des Anhangs auswählen",
    "Attachments saved to Files." : "Anhänge wurde in Dateien gespeichert.",
    "Attachment saved to Files." : "Anhang wurde in Dateien gespeichert.",
    "Error while saving attachments to Files." : "Fehler beim Speichern der Anhänge unter Dateien.",
    "Error while saving attachment to Files." : "Fehler beim Speichern des Anhangs unter Dateien.",
    "Message flag could not be set." : "Nachrichten-Kennzeichnung konnte nicht gesetzt werden.",
    "Could not move message." : "Nachricht konnte nicht verschoben werden.",
    "Invalid account" : "Ungültiges Benutzerkonto",
    "Invalid folder" : "Ungültiger Ordner",
    "Error while creating the account: " : "Fehler beim Erstellen eines Kontos:",
    "Unknown error" : "Unbekannter Fehler",
    "Error while updating the account: " : "Fehler beim Aktualisieren des Kontos:",
    "All inboxes" : "Alle Posteingänge",
    "you" : "Du",
    "Send message to {email}" : "Nachricht an {email} senden",
    "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
    "There was a problem loading {tag}{name}{endtag}" : "Beim Laden von {tag}{name}{endtag} ist ein Problem aufgetreten",
    "Could not load your message" : "Deine Nachricht konnte nicht geladen werden",
    "Could not load the desired message" : "Gewünschte Nachricht konnte nicht geladen werden",
    "Could not load the message" : "Nachricht konnte nicht geladen werden",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n neue Nachricht\nvon {from}","%n neue Nachrichten\nvon {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Save" : "Speichern",
    "Saved" : "Gespeichert",
    "Show all folders" : "Alle Ordner anzeigen",
    "Collapse folders" : "Ordner einklappen",
    "Error while deleting account." : "Fehler beim Löschen des Kontos.",
    "Choose a file to add as attachment" : "Wähle eine Datei, die als Anhang angefügt werden soll",
    "An error occurred while uploading {fname}" : "Fehler aufgetreten beim Hochladen von  {fname}",
    "Reply" : "Antworten",
    "Send" : "Senden",
    "Sending …" : "Sende…",
    "Message sent!" : "Nachricht versandt!",
    "Server error" : "Serverfehler",
    "An unknown error occurred" : "Unbekannter Fehler aufgetreten",
    "Opening HTML drafts is not supported yet." : "Das Öffnen von HTML-Entwürfen wird noch nicht unterstützt.",
    "No writable calendars found" : "Keine beschreibbaren Kalender gefunden",
    "Error while importing the calendar event" : "Fehler beim Importieren des Kalenderereignis",
    "Error while downloading calendar event" : "Fehler beim Herunterladen des Kalenderereignis",
    "& others" : "& weitere",
    "Error while loading messages." : "Fehler beim Laden der Nachrichten.",
    "Error while refreshing messages." : "Fehler beim Aktualisieren der Nachrichten.",
    "Setting up your account" : "Dein Konto wird eingerichtet",
    "Inbox" : "Posteingang",
    "Sent" : "Gesendet",
    "Drafts" : "Entwürfe",
    "Archive" : "Archiv",
    "Trash" : "Papierkorb",
    "Junk" : "Spam",
    "All" : "Alle",
    "Favorites" : "Favoriten",
    "Auto detect failed. Please use manual mode." : "Automatische Erkennung fehlgeschlagen. Bitte nutze den manuellen Modus.",
    "Updating account failed: " : "Kontoaktualisierung fehlgeschlagen:",
    "Creating account failed: " : "Kontoerstellung fehlgeschlagen:",
    "Delete permanently" : "Endgültig löschen",
    "Error loading message" : "Fehler beim Laden der Nachricht",
    "Settings" : "Einstellungen",
    "Forwarding to %s" : "Weiterleiten an %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klicke hier, wenn Du nicht automatisch innerhalb der nächsten Sekunden weitergeleitet wirst.",
    "Redirect" : "Weiterleiten",
    "The link leads to %s" : "Der Link führt nach %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Wenn Du diese Seite nicht besuchen möchtest, kannst Du zu <a href=\"%s\">Mail</a> zurückkehren.",
    "Continue to %s" : "Weiter nach %s",
    "Delete account" : "Konto löschen",
    "Try again" : "Nochmals versuchen",
    "New message" : "Neue Nachricht",
    "Account Settings" : "Konto-Einstellungen",
    "Aliases" : "Aliasse",
    "Mail address" : "E-Mail-Adresse",
    "Display Name" : "Anzeigename",
    "Account" : "Konto",
    "Keyboard shortcuts" : "Tastenkürzel",
    "Speed up your Mail experience with these quick shortcuts." : "Verbessere Deine Arbeit mit Mail durch diese Schnellbefehle.",
    "Compose new message" : "Neue Nachricht erstellen",
    "Newer message" : "Neuere Nachricht",
    "Older message" : "Ältere Nachricht",
    "Toggle star" : "Stern umschalten",
    "Toggle unread" : "Ungelesen umschalten",
    "Delete" : "Löschen",
    "Search" : "Suchen",
    "Refresh" : "Aktualisieren",
    "Connect your mail account" : "Verbinde Deine E-Mail-Konto",
    "Name" : "Name",
    "Mail Address" : "E-Mail-Adresse",
    "Password" : "Passwort",
    "Manual configuration" : "Manuelle Einrichtung",
    "IMAP Host" : "IMAP-Host",
    "IMAP security" : "IMAP-Sicherheit",
    "None" : "Keine",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-Port",
    "IMAP User" : "IMAP-Benutzer",
    "IMAP Password" : "IMAP-Passwort",
    "SMTP Host" : "SMTP-Host",
    "SMTP security" : "SMTP-Sicherheit",
    "SMTP Port" : "SMTP-Port",
    "SMTP User" : "SMTP-Benutzer",
    "SMTP Password" : "SMTP-Passwort",
    "Connect" : "Verbinden",
    "from" : "von",
    "to" : "an",
    "cc" : "cc",
    "bcc" : "bcc",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Diese E-Mail wurde von einer No-Reply-Adresse gesendet und Deine Antwort wird wahrscheinlich nicht gelesen",
    "Subject" : "Betreff",
    "Save all to Files" : "Alles unter Dateien sichern",
    "Add mail account" : "E-Mail-Konto hinzufügen",
    "Use Gravatar and favicon avatars" : "Gravatar- und Favicon-Avatare verwenden",
    "No search results for" : "Keine Suchergebnisse für",
    "The images have been blocked to protect your privacy." : "Die Bilder wurden blockiert um Deine Privatsphäre zu schützen.",
    "Show images from this sender" : "Bilder dieses Absenders anzeigen",
    "Forward" : "Weiterleiten",
    "No messages in this folder" : "Keine Nachrichten in diesem Ordner",
    "Upload attachment" : "Anhang hochladen",
    "Add attachment from Files" : "Anhang von \"Dateien\" hinzufügen",
    "Import into calendar" : "In Kalender importieren",
    "Download attachment" : "Anhang herunterladen",
    "Save to Files" : "Unter Dateien speichern"
},
"nplurals=2; plural=(n != 1);");
